<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:datetime="http://exslt.org/dates-and-times" xmlns:dnsp="http://ACORD.org/Standards/Life/2" xmlns:dtFormatter="xalan://com.pilotfish.eip.gui.mapper.util.DateTimeFormatter" exclude-result-prefixes="datetime dtFormatter" version="1.0">
  <xsl:template match="Policy">
    <dnsp:TXLife Version="2.13.00">
      <dnsp:TXLifeRequest>
        <TransRefGUID>
          <xsl:value-of select="concat(POL-NUMBER,datetime:dateTime())" />
        </TransRefGUID>
        <dnsp:TransType tc="203">Holding Inquiry</dnsp:TransType>
        <TransExeDate>
          <xsl:value-of select="datetime:dateTime()" />
        </TransExeDate>
        <TransExeTime>
          <xsl:value-of select="datetime:date()" />
        </TransExeTime>
        <dnsp:OLifE>
          <dnsp:Holding id="Holding_1">
            <dnsp:HoldingKey Persist="Permanent">Key1</dnsp:HoldingKey>
            <dnsp:HoldingTypeCode tc="5">A policy that contains or is supported by investments i.e. Variable Life</dnsp:HoldingTypeCode>
            <dnsp:AsOfDate>
              <xsl:value-of select="dtFormatter:format(REPORT-ASOF,'yyyyMMdd','yyyy-MM-dd')" />
              <xsl:value-of select="REPORT-ASOF" />
            </dnsp:AsOfDate>
            <dnsp:Policy>
              <xsl:element name="LineOfBusiness">
                <xsl:variable name="var1">
                  <xsl:call-template name="TabularMapping_LOBMapping">
                    <xsl:with-param name="value" select="LINE-BIZ" />
                  </xsl:call-template>
                </xsl:variable>
                <xsl:variable name="var2">
                  <xsl:call-template name="OLI_LU_LINEBUS_TC__To__Description__Mapping">
                    <xsl:with-param name="value" select="$var1" />
                  </xsl:call-template>
                </xsl:variable>
                <xsl:attribute name="tc">
                  <xsl:value-of select="$var1" />
                </xsl:attribute>
                <xsl:value-of select="$var2" />
              </xsl:element>
              <PolNumber>
                <xsl:value-of select="POL-NUMBER" />
              </PolNumber>
              <ProductCode>
                <xsl:value-of select="PROD-CD" />
              </ProductCode>
              <CarrierCode>ACME</CarrierCode>
              <xsl:element name="PolicyStatus">
                <xsl:variable name="var1">
                  <xsl:call-template name="TabularMapping_PolicyStatusMapping">
                    <xsl:with-param name="value" select="POL-STATUS" />
                  </xsl:call-template>
                </xsl:variable>
                <xsl:variable name="var2">
                  <xsl:call-template name="OLI_LU_POLSTAT_TC__To__Description__Mapping">
                    <xsl:with-param name="value" select="$var1" />
                  </xsl:call-template>
                </xsl:variable>
                <xsl:attribute name="tc">
                  <xsl:value-of select="$var1" />
                </xsl:attribute>
                <xsl:value-of select="$var2" />
              </xsl:element>
              <dnsp:ApplicationInfo>
                <TrackingID>
                  <xsl:value-of select="POL-NUMBER" />
                </TrackingID>
              </dnsp:ApplicationInfo>
            </dnsp:Policy>
            <KeyedValue>
              <KeyName>ContractNumber.</KeyName>
              <KeyValue />
              <xsl:value-of select="CONTRACT-NO" />
            </KeyedValue>
          </dnsp:Holding>
        </dnsp:OLifE>
      </dnsp:TXLifeRequest>
    </dnsp:TXLife>
  </xsl:template>
  <xsl:template name="OLI_LU_LINEBUS_TC__To__Description__Mapping">
    <xsl:param name="value" />
    <xsl:choose>
      <xsl:when test="$value='0'">
        <xsl:text>Unknown</xsl:text>
      </xsl:when>
      <xsl:when test="$value='1'">
        <xsl:text>Life</xsl:text>
      </xsl:when>
      <xsl:when test="$value='2'">
        <xsl:text>Annuity</xsl:text>
      </xsl:when>
      <xsl:when test="$value='3'">
        <xsl:text>Disability</xsl:text>
      </xsl:when>
      <xsl:when test="$value='4'">
        <xsl:text>Health</xsl:text>
      </xsl:when>
      <xsl:when test="$value='5'">
        <xsl:text>Long Term Care</xsl:text>
      </xsl:when>
      <xsl:when test="$value='6'">
        <xsl:text>Superannuation</xsl:text>
      </xsl:when>
      <xsl:when test="$value='7'">
        <xsl:text>Critical Illness</xsl:text>
      </xsl:when>
      <xsl:when test="$value='8'">
        <xsl:text>Property and Casualty</xsl:text>
      </xsl:when>
      <xsl:when test="$value='9'">
        <xsl:text>Medicare Supplement</xsl:text>
      </xsl:when>
      <xsl:when test="$value='2147483647'">
        <xsl:text>Other</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>Unknown</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <xsl:template name="TabularMapping_LOBMapping">
    <xsl:param name="value" />
    <xsl:choose>
      <xsl:when test="normalize-space($value)='LIFE'">
        <xsl:text>1</xsl:text>
      </xsl:when>
      <xsl:when test="normalize-space($value)='ANNUTY'">
        <xsl:text>2</xsl:text>
      </xsl:when>
      <xsl:when test="normalize-space($value)='HELTH'">
        <xsl:text>4</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>0</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <xsl:template name="OLI_LU_POLSTAT_TC__To__Description__Mapping">
    <xsl:param name="value" />
    <xsl:choose>
      <xsl:when test="$value='0'">
        <xsl:text>Unknown</xsl:text>
      </xsl:when>
      <xsl:when test="$value='1'">
        <xsl:text>Active (inforce).</xsl:text>
      </xsl:when>
      <xsl:when test="$value='2'">
        <xsl:text>Inactive</xsl:text>
      </xsl:when>
      <xsl:when test="$value='3'">
        <xsl:text>Paid-Up</xsl:text>
      </xsl:when>
      <xsl:when test="$value='4'">
        <xsl:text>Lapsed</xsl:text>
      </xsl:when>
      <xsl:when test="$value='5'">
        <xsl:text>Lapse Pending.</xsl:text>
      </xsl:when>
      <xsl:when test="$value='6'">
        <xsl:text>Surrendered</xsl:text>
      </xsl:when>
      <xsl:when test="$value='7'">
        <xsl:text>Not Taken.</xsl:text>
      </xsl:when>
      <xsl:when test="$value='8'">
        <xsl:text>Pending</xsl:text>
      </xsl:when>
      <xsl:when test="$value='9'">
        <xsl:text>Waiver</xsl:text>
      </xsl:when>
      <xsl:when test="$value='10'">
        <xsl:text>Death Claim Pending.</xsl:text>
      </xsl:when>
      <xsl:when test="$value='11'">
        <xsl:text>Death Claim Paid.</xsl:text>
      </xsl:when>
      <xsl:when test="$value='12'">
        <xsl:text>Proposed</xsl:text>
      </xsl:when>
      <xsl:when test="$value='13'">
        <xsl:text>Canceled - Home Office Cancellation</xsl:text>
      </xsl:when>
      <xsl:when test="$value='14'">
        <xsl:text>Terminated</xsl:text>
      </xsl:when>
      <xsl:when test="$value='15'">
        <xsl:text>Under Disability</xsl:text>
      </xsl:when>
      <xsl:when test="$value='16'">
        <xsl:text>Cash Value Paid.</xsl:text>
      </xsl:when>
      <xsl:when test="$value='17'">
        <xsl:text>Expired</xsl:text>
      </xsl:when>
      <xsl:when test="$value='18'">
        <xsl:text>Extended Term</xsl:text>
      </xsl:when>
      <xsl:when test="$value='19'">
        <xsl:text>Reissue</xsl:text>
      </xsl:when>
      <xsl:when test="$value='20'">
        <xsl:text>Reduced Paid Up</xsl:text>
      </xsl:when>
      <xsl:when test="$value='21'">
        <xsl:text>Applied For</xsl:text>
      </xsl:when>
      <xsl:when test="$value='22'">
        <xsl:text>Pending Transmission (application completed and ready to be sent but transmission has not taken place).</xsl:text>
      </xsl:when>
      <xsl:when test="$value='23'">
        <xsl:text>Incomplete (application was incomplete).</xsl:text>
      </xsl:when>
      <xsl:when test="$value='24'">
        <xsl:text>Approved</xsl:text>
      </xsl:when>
      <xsl:when test="$value='25'">
        <xsl:text>Issued</xsl:text>
      </xsl:when>
      <xsl:when test="$value='26'">
        <xsl:text>Counter offer - made by HO</xsl:text>
      </xsl:when>
      <xsl:when test="$value='27'">
        <xsl:text>Carrier decline to issue</xsl:text>
      </xsl:when>
      <xsl:when test="$value='28'">
        <xsl:text>Carrier decline to reinstate</xsl:text>
      </xsl:when>
      <xsl:when test="$value='29'">
        <xsl:text>Carrier deferred (e.g. carrier is deferring coverage until certain conditions are
         met).</xsl:text>
      </xsl:when>
      <xsl:when test="$value='30'">
        <xsl:text>Conversion with a new number</xsl:text>
      </xsl:when>
      <xsl:when test="$value='31'">
        <xsl:text>Contractual change pending.</xsl:text>
      </xsl:when>
      <xsl:when test="$value='32'">
        <xsl:text>Back Billed</xsl:text>
      </xsl:when>
      <xsl:when test="$value='33'">
        <xsl:text>Illustration declined (deprecated)</xsl:text>
      </xsl:when>
      <xsl:when test="$value='34'">
        <xsl:text>Eligible, Issue Pending (deprecated)</xsl:text>
      </xsl:when>
      <xsl:when test="$value='35'">
        <xsl:text>Declined Not Eligible (deprecated)</xsl:text>
      </xsl:when>
      <xsl:when test="$value='36'">
        <xsl:text>Annuitized</xsl:text>
      </xsl:when>
      <xsl:when test="$value='37'">
        <xsl:text>Reinstated</xsl:text>
      </xsl:when>
      <xsl:when test="$value='38'">
        <xsl:text>Pending Reinstatement</xsl:text>
      </xsl:when>
      <xsl:when test="$value='39'">
        <xsl:text>Canceled - Customer canceled new business app</xsl:text>
      </xsl:when>
      <xsl:when test="$value='40'">
        <xsl:text>Matured</xsl:text>
      </xsl:when>
      <xsl:when test="$value='41'">
        <xsl:text>Conversion Pending</xsl:text>
      </xsl:when>
      <xsl:when test="$value='42'">
        <xsl:text>Grace Period</xsl:text>
      </xsl:when>
      <xsl:when test="$value='43'">
        <xsl:text>Policy was issued with changes</xsl:text>
      </xsl:when>
      <xsl:when test="$value='44'">
        <xsl:text>Issued with Requirements</xsl:text>
      </xsl:when>
      <xsl:when test="$value='45'">
        <xsl:text>Invalid</xsl:text>
      </xsl:when>
      <xsl:when test="$value='46'">
        <xsl:text>Pending Replacement</xsl:text>
      </xsl:when>
      <xsl:when test="$value='47'">
        <xsl:text>Fully Paid-Up</xsl:text>
      </xsl:when>
      <xsl:when test="$value='48'">
        <xsl:text>Active - Preliminary Term</xsl:text>
      </xsl:when>
      <xsl:when test="$value='50'">
        <xsl:text>Canceled - Free Look</xsl:text>
      </xsl:when>
      <xsl:when test="$value='51'">
        <xsl:text>Policy was not placed</xsl:text>
      </xsl:when>
      <xsl:when test="$value='52'">
        <xsl:text>Coverage is "active" but one (or more) of insureds have died</xsl:text>
      </xsl:when>
      <xsl:when test="$value='53'">
        <xsl:text>Conditional Approval (deprecated)</xsl:text>
      </xsl:when>
      <xsl:when test="$value='54'">
        <xsl:text>Submitted to Underwriting</xsl:text>
      </xsl:when>
      <xsl:when test="$value='55'">
        <xsl:text>Suspend</xsl:text>
      </xsl:when>
      <xsl:when test="$value='56'">
        <xsl:text>Re-entry pending</xsl:text>
      </xsl:when>
      <xsl:when test="$value='57'">
        <xsl:text>Quoted</xsl:text>
      </xsl:when>
      <xsl:when test="$value='58'">
        <xsl:text>Approved Tentative Offer</xsl:text>
      </xsl:when>
      <xsl:when test="$value='59'">
        <xsl:text>HO Withdrew</xsl:text>
      </xsl:when>
      <xsl:when test="$value='60'">
        <xsl:text>Producer Withdrew</xsl:text>
      </xsl:when>
      <xsl:when test="$value='61'">
        <xsl:text>Lapsing on a daily cost basis</xsl:text>
      </xsl:when>
      <xsl:when test="$value='62'">
        <xsl:text>Postponed (deprecated)</xsl:text>
      </xsl:when>
      <xsl:when test="$value='63'">
        <xsl:text>Block Conversion</xsl:text>
      </xsl:when>
      <xsl:when test="$value='64'">
        <xsl:text>Conversion with the same number</xsl:text>
      </xsl:when>
      <xsl:when test="$value='65'">
        <xsl:text>Not Taken Out</xsl:text>
      </xsl:when>
      <xsl:when test="$value='89'">
        <xsl:text>Terminated - Reserves Released</xsl:text>
      </xsl:when>
      <xsl:when test="$value='90'">
        <xsl:text>Active Rider Terminated - Policy Converted to NFO (non forfeiture options)</xsl:text>
      </xsl:when>
      <xsl:when test="$value='91'">
        <xsl:text>Paid-Up Rider Terminated - Policy Converted to NFO (non forfeiture options)</xsl:text>
      </xsl:when>
      <xsl:when test="$value='92'">
        <xsl:text>Status of 'member left'</xsl:text>
      </xsl:when>
      <xsl:when test="$value='93'">
        <xsl:text>Status of 'Departure Extension'</xsl:text>
      </xsl:when>
      <xsl:when test="$value='94'">
        <xsl:text>Inforce- Attained Age Conversion</xsl:text>
      </xsl:when>
      <xsl:when test="$value='95'">
        <xsl:text>Disability claim pending without policy termination</xsl:text>
      </xsl:when>
      <xsl:when test="$value='97'">
        <xsl:text>Reconsider and Approve</xsl:text>
      </xsl:when>
      <xsl:when test="$value='98'">
        <xsl:text>FIU New Business Rejection</xsl:text>
      </xsl:when>
      <xsl:when test="$value='99'">
        <xsl:text>Exercised</xsl:text>
      </xsl:when>
      <xsl:when test="$value='100'">
        <xsl:text>Claim pending without policy termination</xsl:text>
      </xsl:when>
      <xsl:when test="$value='103'">
        <xsl:text>Approve - Issue Hold</xsl:text>
      </xsl:when>
      <xsl:when test="$value='106'">
        <xsl:text>Underwriting complete, policy paid</xsl:text>
      </xsl:when>
      <xsl:when test="$value='107'">
        <xsl:text>Underwriting incomplete; policy paid</xsl:text>
      </xsl:when>
      <xsl:when test="$value='108'">
        <xsl:text>Under Retrenchment (Unemployment)</xsl:text>
      </xsl:when>
      <xsl:when test="$value='109'">
        <xsl:text>Request Refused</xsl:text>
      </xsl:when>
      <xsl:when test="$value='110'">
        <xsl:text>Risk Not Acceptable</xsl:text>
      </xsl:when>
      <xsl:when test="$value='111'">
        <xsl:text>Rescinded</xsl:text>
      </xsl:when>
      <xsl:when test="$value='112'">
        <xsl:text>Canceled - no additional information specified</xsl:text>
      </xsl:when>
      <xsl:when test="$value='113'">
        <xsl:text>Dormant</xsl:text>
      </xsl:when>
      <xsl:when test="$value='114'">
        <xsl:text>Canceled - Customer canceled reinstatement request</xsl:text>
      </xsl:when>
      <xsl:when test="$value='115'">
        <xsl:text>FIU Reinstatement Rejection</xsl:text>
      </xsl:when>
      <xsl:when test="$value='2147483647'">
        <xsl:text>Other</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>Unknown</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <xsl:template name="TabularMapping_PolicyStatusMapping">
    <xsl:param name="value" />
    <xsl:choose>
      <xsl:when test="normalize-space($value)='ACTINFRCE'">
        <xsl:text>1</xsl:text>
      </xsl:when>
      <xsl:when test="normalize-space($value)='NEWBUSINS'">
        <xsl:text>11</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>0</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
</xsl:stylesheet>

